@@ -1,5 +1,25 @@
-#ifndef TCLWEB_H
-#define TCLWEB_H
+/* TclWeb.h */
+/*
+    Licensed to the Apache Software Foundation (ASF) under one
+    or more contributor license agreements.  See the NOTICE file
+    distributed with this work for additional information
+    regarding copyright ownership.  The ASF licenses this file
+    to you under the Apache License, Version 2.0 (the
+    "License"); you may not use this file except in compliance
+    with the License.  You may obtain a copy of the License at
+
+      http://www.apache.org/licenses/LICENSE-2.0
+
+    Unless required by applicable law or agreed to in writing,
+    software distributed under the License is distributed on an
+    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+    KIND, either express or implied.  See the License for the
+    specific language governing permissions and limitations
+    under the License.
+*/
+
+#ifndef __tclweb_h__
+#define __tclweb_h__
 
 #include <tcl.h>
 #include "apache_request.h"
@@ -9,8 +29,6 @@
  * 	Common API layer.
  */
 
-/* $Id$ */
-
 /* Tcl 8.4 migration. */
 #ifndef CONST84
 #   define CONST84
@@ -266,4 +284,4 @@ char *TclWeb_GetVirtualFile( TclWebRequest *req, char *virtualname );
 
 /* error (log) ? */
 
-#endif /* TCLWEB_H */
+#endif /* tclweb_h */
