@@ -272,7 +272,7 @@ Rivet_SendContent(rivet_thread_private *private)
         goto sendcleanup;
     }
 
-    if (private->r->header_only && !private->running_conf->honor_header_only_reqs)
+    if (private->r->header_only && !private->running_conf->honor_head_requests)
     {
         TclWeb_SetHeaderType(DEFAULT_HEADER_TYPE, private->req);
         TclWeb_PrintHeaders(private->req);
@@ -288,7 +288,7 @@ Rivet_SendContent(rivet_thread_private *private)
        that concern us. FIXME */
 
     if (USER_CONF_UPDATED(private->running_conf) && (interp_obj->cache_size != 0) && 
-                                                    (interp_obj->cache_free < interp_obj->cache_size)) 
+                                                    (interp_obj->cache_free < interp_obj->cache_size))
     {
         RivetCache_Cleanup(private,interp_obj);
     }
@@ -332,9 +332,9 @@ sendcleanup:
     /* Request processing final stage */
 
     /* A new big catch is the handling of exit commands that are treated
-     * as ::rivet::abort_page. After the AbortScript has been evaluated
-     * the exit condition is checked and in case the exit handler
-     * of the bridge module is called before terminating the whole process
+     * as exception thrown by ::rivet::abort_page. After the AbortScript
+     * has been evaluated the exit condition is checked and the bridge
+     * exit handler is called upon.
      */
     
     if (private->thread_exit)
