@@ -19,8 +19,6 @@
     under the License.
  */
 
-/* $Id$*/
-
 #include <httpd.h>
 #include <math.h>
 #include <tcl.h>
@@ -51,8 +49,9 @@
 
 extern DLLIMPORT mod_rivet_globals* module_globals;
 extern DLLIMPORT apr_threadkey_t*   rivet_thread_key;
+extern DLLIMPORT module             rivet_module;
 
-apr_threadkey_t*        handler_thread_key;
+// apr_threadkey_t* handler_thread_key;
 
 #ifdef RIVET_NO_HAVE_ROUND
 int round(double d) { return (int)(d + 0.5); }
@@ -70,14 +69,14 @@ typedef struct mpm_bridge_status {
     apr_uint32_t*       running_threads_count;
     apr_queue_t*        queue;                  /* jobs queue               */
     void**              workers;                /* thread pool ids          */
-    int                 exit_command;
-    int                 exit_command_status;
     int                 max_threads;
     int                 min_spare_threads;
     int                 max_spare_threads;
 #ifdef RIVET_SERIALIZE_HTTP_REQUESTS
     apr_thread_mutex_t* req_mutex;
 #endif
+    int                 skip_thread_on_exit;   /* To exclusively handle the *
+                                                * WorkerBridge_Shutdown     */
 } mpm_bridge_status;
 
 
@@ -90,7 +89,7 @@ typedef struct _handler_private
 {
     apr_thread_cond_t*      cond;
     apr_thread_mutex_t*     mutex;
-    request_rec*            r;              /* request rec                 */
+    request_rec*            r;                  /* request rec  */
     int                     code;
     int                     status;
     rivet_req_ctype         ctype;
@@ -107,7 +106,7 @@ enum
 };
 
 /* 
- * -- Worker_Bridge_Shutdown
+ * -- WorkerBridge_Shutdown
  *
  * Child process shutdown: no more requests are served and we
  * pop from the queue all the threads sitting for work to do. 
@@ -129,8 +128,62 @@ enum
  * must be restared or (most likely) the child process can exit.
  *
  */
+static
+void WorkerBridge_Shutdown (void)
+{
+    int                 waits;
+    void*               v;
+    handler_private*    thread_obj;
+    apr_status_t        rv;
+    apr_uint32_t        threads_to_stop = 0;
+    int                 not_to_be_waited;
 
-void Worker_Bridge_Shutdown (void)
+    not_to_be_waited = module_globals->mpm->skip_thread_on_exit;
+
+    apr_thread_mutex_lock(module_globals->mpm->job_mutex);
+
+    module_globals->mpm->server_shutdown = 1;
+
+    /* We wake up the supervisor who is now supposed to stop 
+     * all the Tcl worker threads
+     */
+
+    apr_thread_cond_signal(module_globals->mpm->job_cond);
+    apr_thread_mutex_unlock(module_globals->mpm->job_mutex);
+
+    waits = 5;
+    do
+    {
+
+        rv = apr_queue_trypop(module_globals->mpm->queue,&v);
+
+        /* We wait for possible threads that are taking
+         * time to serve requests and haven't had a chance to
+         * see the signal yet
+         */
+
+        if (rv == APR_EAGAIN) 
+        {
+            waits--;
+            apr_sleep(200000);
+            continue;
+        }
+
+        thread_obj = (handler_private*)v;
+        apr_thread_mutex_lock(thread_obj->mutex);
+        thread_obj->status = init;
+        apr_thread_cond_signal(thread_obj->cond);
+        apr_thread_mutex_unlock(thread_obj->mutex);
+
+        threads_to_stop = apr_atomic_read32(module_globals->mpm->threads_count);
+
+    } while ((waits > 0) && (threads_to_stop > not_to_be_waited));
+
+    return;
+}
+
+#if 0
+void WorkerBridge_Shutdown (void)
 {
     int                 waits;
     void*               v;
@@ -138,8 +191,18 @@ void Worker_Bridge_Shutdown (void)
     apr_status_t        rv;
     apr_uint32_t        threads_to_stop;
 
+    apr_thread_mutex_lock(module_globals->mpm->job_mutex);
+
+    module_globals->mpm->server_shutdown = 1;
+
+    /* We wake up the supervisor who is now supposed to stop 
+     * all the Tcl worker threads
+     */
+
+    apr_thread_cond_signal(module_globals->mpm->job_cond);
+    apr_thread_mutex_unlock(module_globals->mpm->job_mutex);
+
     waits = 5;
-    threads_to_stop = apr_atomic_read32(module_globals->mpm->threads_count);
     do
     {
 
@@ -156,6 +219,7 @@ void Worker_Bridge_Shutdown (void)
             apr_sleep(200000);
             continue;
         }
+
         thread_obj = (handler_private*)v;
         apr_thread_mutex_lock(thread_obj->mutex);
         thread_obj->status = init;
@@ -168,9 +232,10 @@ void Worker_Bridge_Shutdown (void)
 
     return;
 }
+#endif
 
 /*
- * -- request_processor_ng
+ * -- request_processor
  */
 
 static void* APR_THREAD_FUNC request_processor (apr_thread_t *thd, void *data)
@@ -209,13 +274,12 @@ static void* APR_THREAD_FUNC request_processor (apr_thread_t *thd, void *data)
     thread_obj = apr_pcalloc(private->pool,sizeof(handler_private));
     ap_assert(apr_thread_cond_create(&(thread_obj->cond), private->pool) == APR_SUCCESS);
     ap_assert(apr_thread_mutex_create(&(thread_obj->mutex),APR_THREAD_MUTEX_UNNESTED,private->pool) 
-                                                                          == APR_SUCCESS);
+                                                                         == APR_SUCCESS);
 
     thread_obj->status = idle;
-
     apr_thread_mutex_unlock(module_globals->mpm->job_mutex); /* unlock job initialization stage */
 
-        /* eventually we increment the number of active threads */
+    /* eventually we increment the number of active threads */
 
     apr_atomic_inc32(module_globals->mpm->threads_count);
 
@@ -255,14 +319,14 @@ static void* APR_THREAD_FUNC request_processor (apr_thread_t *thd, void *data)
 
         private->ctype = thread_obj->ctype;
         private->req_cnt++;
+        private->r = thread_obj->r;
 
-        HTTP_REQUESTS_PROC(thread_obj->code = Rivet_SendContent(private,thread_obj->r));
+        HTTP_REQUESTS_PROC(thread_obj->code = Rivet_SendContent(private));
 
         thread_obj->status = done;
-        if (private->thread_exit) thread_obj->status = child_exit;
+        // if (private->thread_exit) thread_obj->status = child_exit;
 
         apr_thread_cond_signal(thread_obj->cond);
-
         while (thread_obj->status != idle)
         {
             apr_thread_cond_wait(thread_obj->cond,thread_obj->mutex);
@@ -272,11 +336,11 @@ static void* APR_THREAD_FUNC request_processor (apr_thread_t *thd, void *data)
     } while (private->ext->keep_going > 0);
 
     apr_thread_mutex_unlock(thread_obj->mutex);
-    ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, module_globals->server, "processor thread orderly exit");
+    ap_log_error(APLOG_MARK,APLOG_DEBUG,0,module_globals->server,"processor thread orderly exit");
 
-    /* We don't clean up the thread resources anymore, if the thread exits the whole process terminates
-     * As long as Tcl can't safely delete interpreters this is the way things must be done */
-    // Rivet_ProcessorCleanup(private);
+    /* We reestablish the single thread and interpreter cleanup */
+    
+    Rivet_ProcessorCleanup(private);
 
     apr_thread_mutex_lock(module_globals->mpm->job_mutex);
     *(apr_thread_t **) apr_array_push(module_globals->mpm->exiting) = thd;
@@ -313,9 +377,9 @@ static void start_thread_pool (int nthreads)
 
         if (rv != APR_SUCCESS) 
         {
-            char    errorbuf[512];
+            char    errorbuf[RIVET_MSG_BUFFER_SIZE];
 
-            apr_strerror(rv, errorbuf,200);
+            apr_strerror(rv, errorbuf,RIVET_MSG_BUFFER_SIZE);
             ap_log_error(APLOG_MARK, APLOG_ERR, APR_EGENERAL, module_globals->server, 
                 "Error starting request_processor thread (%d) rv=%d:%s\n",i,rv,errorbuf);
             exit(1);
@@ -355,7 +419,7 @@ static void supervisor_housekeeping (void)
  * 
  * This function runs within a single thread and to the
  * start and stop of Tcl worker thread pool. It could be extended also
- * provide some basic monitoring data. 
+ * to provide some basic monitoring data. 
  *
  * As we don't delete Tcl interpreters anymore because it can lead
  * to seg faults or delays the supervisor threads doesn't restart
@@ -408,19 +472,19 @@ static void* APR_THREAD_FUNC threaded_bridge_supervisor (apr_thread_t *thd, void
                     /* terminated thread restart */
 
                     rv = create_worker_thread (&((apr_thread_t **)mpm->workers)[i]);
-                    if (rv != APR_SUCCESS) {
-                        char errorbuf[512];
+                    if (rv != APR_SUCCESS) 
+                    {
+                        char errorbuf[RIVET_MSG_BUFFER_SIZE];
 
                         /* we shouldn't ever be in the condition of not being able to start a new thread
                          * Whatever is the reason we log a message and terminate the whole process
                          */
 
-                        apr_strerror(rv,errorbuf,200);
+                        apr_strerror(rv,errorbuf,RIVET_MSG_BUFFER_SIZE);
                         ap_log_error(APLOG_MARK, APLOG_ERR, APR_EGENERAL, s, 
                             "Error starting request_processor thread (%d) rv=%d:%s",i,rv,errorbuf);
 
                         exit(1);
-
                     }
                     
                     break;
@@ -428,15 +492,8 @@ static void* APR_THREAD_FUNC threaded_bridge_supervisor (apr_thread_t *thd, void
             }       
         }   
         apr_thread_mutex_unlock(mpm->job_mutex);
-    }  while (!mpm->server_shutdown);
 
-    Worker_Bridge_Shutdown();
-    
-    if (module_globals->mpm->exit_command)
-    {
-        ap_log_error(APLOG_MARK,APLOG_DEBUG,APR_SUCCESS,module_globals->server,"Orderly child process exits.");
-        exit(module_globals->mpm->exit_command_status);
-    }
+    }  while (!mpm->server_shutdown);
 
     ap_log_error(APLOG_MARK,APLOG_DEBUG,APR_SUCCESS,module_globals->server,"Worker bridge supervisor shuts down");
     apr_thread_exit(thd,APR_SUCCESS);
@@ -444,10 +501,8 @@ static void* APR_THREAD_FUNC threaded_bridge_supervisor (apr_thread_t *thd, void
     return NULL;
 }
 
-// int Worker_MPM_ServerInit (apr_pool_t *pPool, apr_pool_t *pLog, apr_pool_t *pTemp, server_rec *s) { return OK; }
-
 /*
- * -- Worker_MPM_ChildInit
+ * -- WorkerBridge_ChildInit
  *
  * Child initialization function called by the web server framework.
  * For this bridge tasks are 
@@ -458,7 +513,7 @@ static void* APR_THREAD_FUNC threaded_bridge_supervisor (apr_thread_t *thd, void
  * 
  */
 
-void Worker_MPM_ChildInit (apr_pool_t* pool, server_rec* server)
+void WorkerBridge_ChildInit (apr_pool_t* pool, server_rec* server)
 {
     apr_status_t        rv;
     
@@ -472,7 +527,8 @@ void Worker_MPM_ChildInit (apr_pool_t* pool, server_rec* server)
 
     module_globals->mpm = apr_pcalloc(pool,sizeof(mpm_bridge_status));
 
-    /* apr_calloc is supposed to allocate zerod memory, but we still make esplicit the initialization
+    /* apr_calloc is supposed to allocate zeroed memory,
+     * but we still make esplicit the initialization
      * of some of its fields
      */
 
@@ -482,7 +538,8 @@ void Worker_MPM_ChildInit (apr_pool_t* pool, server_rec* server)
     module_globals->mpm->max_spare_threads  = 0;
     module_globals->mpm->workers            = NULL;
     module_globals->mpm->server_shutdown    = 0;
-    module_globals->mpm->exit_command       = 0;
+    //module_globals->mpm->exit_command     = 0;
+    module_globals->mpm->skip_thread_on_exit = 0;
 
     /* We keep some atomic counters that could provide basic data for a workload balancer */
 
@@ -496,7 +553,7 @@ void Worker_MPM_ChildInit (apr_pool_t* pool, server_rec* server)
 
     /* This is the thread key for the framework thread calling the content generation callback */
 
-    ap_assert (apr_threadkey_private_create(&handler_thread_key,NULL,pool) == APR_SUCCESS);
+    // ap_assert (apr_threadkey_private_create(&handler_thread_key,NULL,pool) == APR_SUCCESS);
 
     /* This bridge keeps an array of the ids of threads about to exit. This array is protected by
      * the mutex module_globals->job_mutex and signals through module_globals->job_cond
@@ -514,8 +571,9 @@ void Worker_MPM_ChildInit (apr_pool_t* pool, server_rec* server)
         exit(1);
     }
 
-    /* In order to set up some workload balancing let's 
-     * query apache for some configuration parameters of the worker MPM 
+    /* In order to set up some workload balancing let's
+     * query apache some configuration parameters of
+     * the worker MPM 
      */
 
     if (ap_mpm_query(AP_MPMQ_MAX_THREADS,&module_globals->mpm->max_threads) != APR_SUCCESS)
@@ -539,9 +597,9 @@ void Worker_MPM_ChildInit (apr_pool_t* pool, server_rec* server)
                             threaded_bridge_supervisor, server, module_globals->pool);
 
     if (rv != APR_SUCCESS) {
-        char    errorbuf[512];
+        char errorbuf[RIVET_MSG_BUFFER_SIZE];
 
-        apr_strerror(rv, errorbuf,200);
+        apr_strerror(rv, errorbuf,RIVET_MSG_BUFFER_SIZE);
         ap_log_error(APLOG_MARK, APLOG_ERR, rv, server, 
                      MODNAME "Error starting supervisor thread rv=%d:%s\n",rv,errorbuf);
         exit(1);
@@ -571,13 +629,13 @@ apr_status_t Worker_RequestPrivateCleanup (void *client_data)
                  MODNAME ": request thread private data released");
 
     /* we have to invalidate the data pointer */
+    // apr_threadkey_private_set (NULL,handler_thread_key);
 
-    apr_threadkey_private_set (NULL,handler_thread_key);
     return APR_SUCCESS;
 }
 
 /*
- * -- Worker_MPM_Request
+ * -- WorkerBridge_Request
  *
  * Content generation callback. Actually this function is not
  * generating directly content but instead builds a handler_private 
@@ -597,7 +655,7 @@ apr_status_t Worker_RequestPrivateCleanup (void *client_data)
  *   HTTP status code (see the Apache HTTP web server documentation)
  */
 
-int Worker_MPM_Request (request_rec* r,rivet_req_ctype ctype)
+int WorkerBridge_Request (request_rec* r,rivet_req_ctype ctype)
 {
     void*           v;
     apr_queue_t*    q = module_globals->mpm->queue;
@@ -654,47 +712,29 @@ int Worker_MPM_Request (request_rec* r,rivet_req_ctype ctype)
 }
 
 /* 
- * -- Worker_MPM_Finalize
+ * -- WorkerBridge_Finalize
  *
  *
  */
 
-apr_status_t Worker_MPM_Finalize (void* data)
+apr_status_t WorkerBridge_Finalize (void* data)
 {
     apr_status_t  rv;
     apr_status_t  thread_status;
     server_rec* s = (server_rec*) data;
-    
-    apr_thread_mutex_lock(module_globals->mpm->job_mutex);
-    module_globals->mpm->server_shutdown = 1;
 
-    /* We wake up the supervisor who is now supposed to stop 
-     * all the Tcl worker threads
-     */
+    WorkerBridge_Shutdown();
 
-    apr_thread_cond_signal(module_globals->mpm->job_cond);
-    apr_thread_mutex_unlock(module_globals->mpm->job_mutex);
-
-    /* If the Function is called by the memory pool cleanup we wait
-     * to join the supervisor, otherwise we if the function was called
-     * by Worker_MPM_Exit we skip it because this thread itself must exit
-     * to allow the supervisor to exit in the shortest possible time 
-     */
-
-    if (!module_globals->mpm->exit_command)
+    rv = apr_thread_join (&thread_status,module_globals->mpm->supervisor);
+    if (rv != APR_SUCCESS)
     {
-        rv = apr_thread_join (&thread_status,module_globals->mpm->supervisor);
-        if (rv != APR_SUCCESS)
-        {
-            ap_log_error(APLOG_MARK, APLOG_ERR, rv, s,
-                         MODNAME ": Error joining supervisor thread");
-        }
+        ap_log_error(APLOG_MARK,APLOG_ERR,rv,s,MODNAME": Error joining supervisor thread");
     }
 
-    // apr_threadkey_private_delete (handler_thread_key);
     return OK;
 }
 
+
 /*
  * -- MPM_MasterInterp
  *
@@ -710,17 +750,18 @@ rivet_thread_interp* MPM_MasterInterp(server_rec* s)
 {
     rivet_thread_private*   private;
     rivet_thread_interp*    interp_obj; 
+    rivet_server_conf*      rsc = RIVET_SERVER_CONF(s->module_config);
 
     RIVET_PRIVATE_DATA_NOT_NULL(rivet_thread_key,private)
 
-    interp_obj = Rivet_NewVHostInterp(private->pool,s);
+    interp_obj = Rivet_NewVHostInterp(private->pool,rsc->default_cache_size);
     interp_obj->channel = private->channel;
     Rivet_PerInterpInit(interp_obj, private, s, private->pool);
     return interp_obj;
 }
 
 /*
- * -- Worker_MPM_ExitHandler
+ * -- WorkerBridge_ExitHandler
  *  
  *  Signals a thread to exit by setting the loop control flag to 0
  * and by returning a Tcl error with error code THREAD_EXIT_CODE
@@ -733,12 +774,8 @@ rivet_thread_interp* MPM_MasterInterp(server_rec* s)
  *  the thread running the Tcl script will exit 
  */
 
-int Worker_MPM_ExitHandler(int code)
+int WorkerBridge_ExitHandler(rivet_thread_private* private)
 {
-    rivet_thread_private*   private;
-
-    RIVET_PRIVATE_DATA_NOT_NULL(rivet_thread_key,private)
-
     /* This is not strictly necessary, because this command will 
      * eventually terminate the whole processes */
 
@@ -746,18 +783,64 @@ int Worker_MPM_ExitHandler(int code)
 
     private->ext->keep_going = 0;
 
-    module_globals->mpm->exit_command = 1;
-    module_globals->mpm->exit_command_status = code;
+    //module_globals->mpm->exit_command = 1;
+    //module_globals->mpm->exit_command_status = private->exit_status;
 
-    /* We now tell the supervisor to terminate the Tcl worker thread pool to exit
-     * and is sequence the whole process to shutdown by calling exit() */
- 
-    Worker_MPM_Finalize (private->r->server);
+    if (!module_globals->single_thread_exit)
+    {
+
+        module_globals->mpm->skip_thread_on_exit = 1;
+
+        /* We now tell the supervisor to terminate the Tcl worker thread pool to exit
+         * and is sequence the whole process to shutdown by calling exit() */
+
+        WorkerBridge_Finalize(private->r->server);
+    
+        exit(private->exit_status);
+    } 
+
+    /*
+     * If single thread exit is enabled we continue and let the
+     * thread exit on its own interrupting the main loop
+     */
 
     return TCL_OK;
 }
 
-rivet_thread_interp* Worker_MPM_Interp (rivet_thread_private* private,
+
+#if 0
+int WorkerBridge_ExitHandler(rivet_thread_private* private)
+{
+    /* This is not strictly necessary, because this command will 
+     * eventually terminate the whole processes
+     */
+
+    /* By setting this flag to 0 we let the thread exit when the
+     * request processing has completed 
+     */
+
+    private->ext->keep_going = 0;
+
+    module_globals->mpm->exit_command = 1;
+    module_globals->mpm->exit_command_status = private->exit_status;
+
+    /* In case single_thread_exit we return preparing this thread to exit */
+ 
+    if (!private->running_conf->single_thread_exit) 
+    {
+        /* We now tell the supervisor to terminate the Tcl worker 
+         * thread pool to exit and is sequence the whole process to
+         * shutdown by calling exit()
+         */
+
+        WorkerBridge_Finalize (private->r->server);
+
+    }
+    
+    return TCL_OK;
+}
+#endif
+rivet_thread_interp* WorkerBridge_Interp (rivet_thread_private* private,
                                          rivet_server_conf*    conf,
                                          rivet_thread_interp*  interp)
 {
@@ -766,12 +849,33 @@ rivet_thread_interp* Worker_MPM_Interp (rivet_thread_private* private,
     return private->ext->interps[conf->idx];   
 }
 
+/*
+ *  -- WorkerBridge_ServerInit
+ *
+ * Bridge server wide inizialization:
+ *
+ *  We set the default value of the flag single_thread_exit 
+ *  stored in the module globals
+ *
+ */
+
+int WorkerBridge_ServerInit (apr_pool_t* pPool,apr_pool_t* pLog,apr_pool_t* pTemp,server_rec* s)
+{
+    if (module_globals->single_thread_exit == SINGLE_THREAD_EXIT_UNDEF)
+    {
+        module_globals->single_thread_exit = 1;
+    }
+    return OK;
+}
+
+/* Table of bridge control functions */
+
 DLLEXPORT
 RIVET_MPM_BRIDGE {
-    NULL,
-    Worker_MPM_ChildInit,
-    Worker_MPM_Request,
-    Worker_MPM_Finalize,
-    Worker_MPM_ExitHandler,
-    Worker_MPM_Interp
+    WorkerBridge_ServerInit,
+    WorkerBridge_ChildInit,
+    WorkerBridge_Request,
+    WorkerBridge_Finalize,
+    WorkerBridge_ExitHandler,
+    WorkerBridge_Interp
 };
